@@ -12,4 +12,6 @@
 #' @param rhs A function call using the magrittr semantics.
 #' @return The result of calling `rhs(lhs)`.
 NULL
-utils::globalVariables(c("variable",'id2', 'i.Genotype', "Genotype", 'name', 'new.value','i.value', 'value', '.'))
+utils::globalVariables(c("."))
+utils::globalVariables(c("bind_cols"))
+
